ErrorExt

Trait ErrorExt 

pub trait ErrorExt {
    // Required methods
    fn id(&self) -> Cow<'_, str>;
    fn err_clone(&self) -> Error;
}
Extension trait to extract a name from a Tx5 core error type.

Required Methods

fn id(&self) -> Cow<'_, str>

Get the identifier of this error type, or the string representation.

fn err_clone(&self) -> Error

Clone the error maintaining any meta info is available if we are a tx5 error type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ErrorExt for Error

Source

fn id(&self) -> Cow<'_, str>

Source

fn err_clone(&self) -> Error

Implementors

Source

impl ErrorExt for tx5_core::Error