Enum tx5_core::wire::Wire

source ·
pub enum Wire {
    AuthReqV1 {
        srv_pub: Id,
        nonce: Nonce,
        cipher: Cipher,
        ice: Value,
    },
    AuthResV1 {
        con_key: Id,
        req_addr: bool,
    },
    FwdV1 {
        rem_pub: Id,
        nonce: Nonce,
        cipher: Cipher,
    },
    DemoV1 {
        rem_pub: Id,
    },
}
Tx5 signal server wire protocol for client to server communication.

Variants



AuthReqV1

When a client connects to a server, the server sends an initial authentication / hello request.

Fields

srv_pub: Id

The x25519 public key of this server.

nonce: Nonce

The crypto box nonce for the encoded con_key.

cipher: Cipher

An encoded con_key that must be returned in the AuthResV1 response.

ice: Value

iceServers configuration associated with this webrtc signal server.



AuthResV1

On receiving an AuthReqV1, a client should respond with this AuthResV1.

Fields

con_key: Id

The decoded con_key proving we have a private key associated with our public key.

req_addr: bool

If we would like the server to consider us addressable, send true here. A server may have a limited number of addressable slots.



FwdV1

A client sends an encrypted message to another client.

Fields

rem_pub: Id

The remote id to send this message to, or that this message came from.

nonce: Nonce

The crypto box nonce for the encoded FwdInnerV1 message.

cipher: Cipher

The cipher bytes for the encoded FwdInnerV1 message.



DemoV1

As a standin for bootstrapping, clients may trigger “demo” broadcasts announcing themselves to everyone else connected on the signal server. If “demo” mode is not enabled, sending a demo command may cause a ban.

Fields

rem_pub: Id

The client pub key to announce.

Implementations

source

impl Wire

source

pub fn decode(wire: &[u8]) -> Result<Self>

Decode from wire format (json).

source

pub fn encode(&self) -> Result<Vec<u8>>

Encode into wire format (json).