Tx5-signal wire-level protocol encoding utilities.
Structs
- Cipher data for crypto_box.
- 24 byte nonce for crypto_box cipher.
Enums
- The internal message that is encrypted and forwarded between clients.
- Tx5 signal server wire protocol for client to server communication.