pub enum Wire {
AuthReqV1 {
srv_pub: Id,
nonce: Nonce,
cipher: Cipher,
ice: Value,
},
AuthResV1 {
con_key: Id,
req_addr: bool,
},
FwdV1 {
rem_pub: Id,
nonce: Nonce,
cipher: Cipher,
},
DemoV1 {
rem_pub: Id,
},
}Expand description
Tx5 signal server wire protocol for client to server communication.
Variants
AuthReqV1
Fields
When a client connects to a server, the server sends an initial authentication / hello request.
AuthResV1
Fields
On receiving an AuthReqV1, a client should respond with this AuthResV1.
FwdV1
Fields
A client sends an encrypted message to another client.
DemoV1
As a standin for bootstrapping, clients may trigger “demo” broadcasts announcing themselves to everyone else connected on the signal server. If “demo” mode is not enabled, sending a demo command may cause a ban.
Implementations